#property indicator_chart_window

// Elliott wave counting with MACD and Stochastics divergence
#property indicator_buffers 0
#property indicator_color1 Blue
#property indicator_color2 Red

extern bool soundAlertOn=true;

int start() {
   int wave = iFractals(_Symbol,0);
   if(wave>0) wave=wave+1;
   if(wave==3) wave=2;
   
   // Stochastics
   double k[];
   double d[];
   ArraySetAsSeries(k, true);
   ArraySetAsSeries(d, true);
   int stoch = iStochastic(_Symbol, _Period, 5, 3, 3, MODE_SMA, 0, MODE_MAIN, 0);
   int copied = CopyBuffer(stoch, 0, 0, 2, k);
   if (copied == 0) {
      Print("Failed to copy buffer for Stochastics");
      return -1;
   }
   copied = CopyBuffer(stoch, 1, 0, 2, d);
   if (copied == 0) {
      Print("Failed to copy buffer for Stochastics");
      return -1;
   }
   
   // MACD divergence
   double macd[];
   double signal[];
   double hist[];
   ArraySetAsSeries(macd, true);
   ArraySetAsSeries(signal, true);
   ArraySetAsSeries(hist, true);
   int macdHandle = iMACD(_Symbol, _Period, 12, 26, 9, PRICE_CLOSE);
   copied = CopyBuffer(macdHandle, 0, 0, 2, macd);
   if (copied == 0) {
      Print("Failed to copy buffer for MACD");
      return -1;
   }
   copied = CopyBuffer(macdHandle, 1, 0, 2, signal);
   if (copied == 0) {
      Print("Failed to copy buffer for MACD");
      return -1;
   }
   copied = CopyBuffer(macdHandle, 2, 0, 2, hist);
   if (copied == 0) {
      Print("Failed to copy buffer for MACD");
      return -1;
   }
   double macdDivergence = iBullish(_Symbol, _Period, MODE_MACD, 12, 26, 9, 0, 0) - iBearish(_Symbol, _Period, MODE_MACD, 12, 26, 9, 0, 0);
   
   // Stochastics divergence
   double stochDivergence = iBullish(_Symbol, _Period, MODE_STOCHASTIC, 5, 3, 3, 0, 0) - iBearish(_Symbol, _Period, MODE_STOCHASTIC, 5, 3, 3, 0, 0);
   
   // Check for oversold and overbought conditions
   bool oversold = (k[0] < 20 && d[0] < 20);
   bool overbought = (k[0] > 80 && d[0] > 80);
   
   // Filter trades using higher timeframe
   bool uptrend = iMA(_Symbol, PERIOD_H4, 50, 0, MODE_SMA, PRICE_CLOSE, 0) > iMA(_Symbol, PERIOD_H4, 200, 0, MODE_SMA, PRICE_CLOSE,
// Place buy and sell arrows based on Elliott wave count and indicators
if (wave == 5 && macd[0] < macd[1] && stochDivergence > 0 && oversold && uptrend) {
ObjectCreate("BuyArrow", OBJ_ARROW, 0, Time[0], Low[0] - (2 * Point));
ObjectSet("BuyArrow", OBJPROP_ARROWCODE, 234);
ObjectSet("BuyArrow", OBJPROP_COLOR, Blue);
if (soundAlertOn) {
PlaySound("alert.wav");
}
} else if (wave == 2 && macd[0] > macd[1] && stochDivergence < 0 && overbought && uptrend) {
ObjectCreate("SellArrow", OBJ_ARROW, 0, Time[0], High[0] + (2 * Point));
ObjectSet("SellArrow", OBJPROP_ARROWCODE, 234);
ObjectSet("SellArrow", OBJPROP_COLOR, Red);
if (soundAlertOn) {
PlaySound("alert.wav");
}
} else if (wave == 4 && macd[0] < macd[1] && stochDivergence > 0 && oversold && uptrend) {
ObjectCreate("BuyArrow", OBJ_ARROW, 0, Time[0], Low[0] - (2 * Point));
ObjectSet("BuyArrow", OBJPROP_ARROWCODE, 234);
ObjectSet("BuyArrow", OBJPROP_COLOR, Blue);
if (soundAlertOn) {
PlaySound("alert.wav");
}
} else if (wave == 'c' && macd[0] < macd[1] && stoch[0] > stoch[1] && uptrend) {
ObjectCreate("SellArrow", OBJ_ARROW, 0, Time[0], High[0] + (2 * Point));
ObjectSet("SellArrow", OBJPROP_ARROWCODE, 234);
ObjectSet("SellArrow", OBJPROP_COLOR, Red);
if (soundAlertOn) {
PlaySound("alert.wav");
}
} else if (wave == 'b' && macd[0] > macd[1] && stoch[0] < stoch[1] && uptrend) {
ObjectCreate("BuyArrow", OBJ_ARROW, 0, Time[0], Low[0] - (2 * Point));
ObjectSet("BuyArrow", OBJPROP_ARROWCODE, 234);
ObjectSet("BuyArrow", OBJPROP_COLOR, Blue);
if (soundAlertOn) {
PlaySound("alert.wav");
}
}

return(0);
}